@@ -1,5 +1,5 @@
 package Net::Async::Ping::TCP;
-$Net::Async::Ping::TCP::VERSION = '0.001000';
+$Net::Async::Ping::TCP::VERSION = '0.001001';
 use Moo;
 use warnings NONFATAL => 'all';
 
@@ -43,15 +43,15 @@ sub ping {
       $loop->timeout_future(after => $timeout)
    )
    ->then(
-      sub { Future->wrap(Time::HiRes::tv_interval($t0)) },
+      sub { Future->done(Time::HiRes::tv_interval($t0)) },
       sub {
          my ($human, $layer) = @_;
          my $ex    = pop;
-         if ($layer eq 'connect') {
-            return Future->wrap(Time::HiRes::tv_interval($t0))
+         if ($layer && $layer eq 'connect') {
+            return Future->done(Time::HiRes::tv_interval($t0))
                if !$service_check && $ex == ECONNREFUSED;
          }
-         Future->new->die(Time::HiRes::tv_interval($t0))
+         Future->fail(Time::HiRes::tv_interval($t0))
       },
    )
 }
@@ -70,7 +70,7 @@ Net::Async::Ping::TCP
 
 =head1 VERSION
 
-version 0.001000
+version 0.001001
 
 =head1 AUTHOR
 
@@ -78,7 +78,7 @@ Arthur Axel "fREW" Schmidt <frioux+cpan@gmail.com>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2014 by Arthur Axel "fREW" Schmidt.
+This software is copyright (c) 2015 by Arthur Axel "fREW" Schmidt.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
